@@ -1,6 +1,8 @@
 from django.contrib.auth import authenticate, get_user_model
+from django.db import transaction
 from django.utils import six
 from django.utils.module_loading import import_string
+
 from rest_framework import exceptions, serializers
 from rest_framework.authtoken.models import Token
 
@@ -37,10 +39,13 @@ class UserRegistrationSerializer(serializers.ModelSerializer):
         )
 
     def create(self, validated_data):
-        user = User.objects.create_user(**validated_data)
         if settings.get('SEND_ACTIVATION_EMAIL'):
-            user.is_active = False
-            user.save(update_fields=['is_active'])
+            with transaction.atomic():
+                user = User.objects.create_user(**validated_data)
+                user.is_active = False
+                user.save(update_fields=['is_active'])
+        else:
+            user = User.objects.create_user(**validated_data)
         return user
 
 
@@ -70,6 +75,16 @@ class LoginSerializer(serializers.Serializer):
 class PasswordResetSerializer(serializers.Serializer):
     email = serializers.EmailField()
 
+    default_error_messages = {
+        'email_not_found': constants.EMAIL_NOT_FOUND
+    }
+
+    def validate_email(self, value):
+        if settings.get('PASSWORD_RESET_SHOW_EMAIL_NOT_FOUND') and \
+                not self.context['view'].get_users(value):
+            raise serializers.ValidationError(self.error_messages['email_not_found'])
+        return value
+
 
 class UidAndTokenSerializer(serializers.Serializer):
     uid = serializers.CharField()
